package com.gic.haoban.manage.service.service.impl;

import com.gic.commons.util.EntityUtil;
import com.gic.haoban.common.utils.StringUtil;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.service.dao.mapper.StaffMapper;
import com.gic.haoban.manage.service.dao.mapper.WxEnterpriseMapper;
import com.gic.haoban.manage.service.entity.TabHaobanStaff;
import com.gic.haoban.manage.service.entity.TabHaobanWxEnterprise;
import com.gic.haoban.manage.service.service.MemberUnionRelatedService;
import com.gic.haoban.manage.service.service.StaffService;
import com.github.pagehelper.Page;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Set;

@Service
public class StaffServiceImpl implements StaffService {
    private static final Logger log = LogManager.getLogger(StaffServiceImpl.class);

    @Autowired
    private StaffMapper mapper;
    @Autowired
    private MemberUnionRelatedService memberUnionRelatedService;
    @Autowired
    private WxEnterpriseMapper wxEnterpriseMapper;

    @Override
    public TabHaobanStaff selectById(String id) {
        return mapper.selectByPrimaryKey(id);
    }

    @Override
    public TabHaobanStaff selectByNationcodeAndPhoneNumber(String wxEnterpriseId, String nationcode, String phoneNumber) {
        if (StringUtils.isBlank(phoneNumber)) {
            return null;
        }
        return mapper.selectByNationcodeAndPhoneNumber(wxEnterpriseId, nationcode, phoneNumber);
    }

    @Override
    public String add(TabHaobanStaff tab) {
        Date now = new Date();
        tab.setCreateTime(now);
        tab.setUpdateTime(now);
        if (StringUtils.isBlank(tab.getStaffId())) {
            tab.setStaffId(StringUtil.randomUUID());
        }
        tab.setStatusFlag(1);
//		if(StringUtils.isBlank(tab.getWxUserId())){
//			tab.setWxUserId(tab.getStaffId());
//		}
        mapper.insertSelective(tab);
        return tab.getStaffId();
    }

    @Override
    public Page<TabHaobanStaff> pageStaff(Set<String> staffIds, Integer activeFlag, String keyword) {

        return mapper.pageStaff(staffIds, activeFlag, keyword);
    }

    @Override
    public TabHaobanStaff selectByUserIdAndEnterpriseId(String userId, String wxEnterpriseId) {
        TabHaobanWxEnterprise tabHaobanWxEnterprise = wxEnterpriseMapper.selectByPrimaryKey(wxEnterpriseId);
        if (tabHaobanWxEnterprise == null) {
            return null;
        }
        String corpid = tabHaobanWxEnterprise.getCorpid();
        log.info("corpid：{}", corpid);
        if (corpid.length() > 20 && userId.length() == 32) {
            return mapper.selectByOpenUserIdAndEnterpriseId(userId, wxEnterpriseId);
        } else {
            return mapper.selectByUserIdAndEnterpriseId(userId, wxEnterpriseId);
        }
    }

    @Override
    public void updateByPrimaryKey(TabHaobanStaff tab) {
        tab.setUpdateTime(new Date());
        mapper.updateByPrimaryKeySelective(tab);
    }

    @Override
    public int delByuserid(String staffId) {
        TabHaobanStaff staff = new TabHaobanStaff();
        staff.setStaffId(staffId);
        staff.setStatusFlag(0);
        return this.mapper.updateByPrimaryKeySelective(staff);
    }

    @Override
    public List<StaffDTO> listByUserIdsAndWxEnterpriseId(List<String> userIds, String wxEnterpriseId) {
        return EntityUtil.changeEntityListByJSON(StaffDTO.class, this.mapper.listByUserIdsAndWxEnterpriseId(userIds, wxEnterpriseId));
    }

    @Override
    public int cleanStaff(String wxEnterpriseId, List<String> staffIds) {
        memberUnionRelatedService.cleanStaffRelated(wxEnterpriseId, staffIds);
        return mapper.cleanStaff(wxEnterpriseId, staffIds);
    }

    @Override
    public TabHaobanStaff getWxStaffByOne(String wxEnterpriseId) {
        return mapper.getWxStaffByOne(wxEnterpriseId);
    }

    @Override
    public List<String> listDelUserStaffId(String wxEnterpriseId, List<String> staffIds) {
        return mapper.listUserStaffId(wxEnterpriseId, staffIds);
    }

    @Override
    public List<TabHaobanStaff> listNoStatusByStaffIds(String wxEnterpriseId, List<String> staffIds) {
        return mapper.listNoStatusStaffIds(wxEnterpriseId, staffIds);
    }

    @Override
    public List<StaffDTO> listByOpenUserIdsAndWxEnterpriseId(List<String> openUserIds, String wxEnterpriseId) {
        return EntityUtil.changeEntityListByJSON(StaffDTO.class, mapper.listByOpenUserIdsAndWxEnterpriseId(openUserIds, wxEnterpriseId));
    }

    @Override
    public int updateOpenUserIdsByUserId(String wxEnterpriseId, String wxUserId, String wxOpenUseId) {
        return mapper.updateOpenUserIdsByUserId(wxEnterpriseId, wxUserId, wxOpenUseId);
    }

    @Override
    public TabHaobanStaff selectByCorpidAndUserIdAndEnterpriseId(String corpid, String userId, String wxEnterpriseId) {
        if (corpid.length() > 20) {
            return mapper.selectByOpenUserIdAndEnterpriseId(userId, wxEnterpriseId);
        } else {
            return mapper.selectByUserIdAndEnterpriseId(userId, wxEnterpriseId);
        }
    }
}
