package com.gic.haoban.manage.web.interceptor;

import com.alibaba.fastjson.JSONObject;
import com.gic.haoban.common.anno.IgnoreLogin;
import com.gic.haoban.common.utils.AuthRequestWellDoneUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.WellDoneLoginDTO;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.redis.data.util.GicRateLimiter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Map;

/**
 * Created 2018/7/20.
 *
 * @author hua
 */
public class MobileWebInterceptor extends HandlerInterceptorAdapter {

    private static final Logger logger = LoggerFactory.getLogger(MobileWebInterceptor.class);

    private static final String MOUDLE = "haoban-manage3-wx";


    private void errorResult(HttpServletResponse httpServletResponse, HaoBanErrCode errCode) {
        HaobanResponse response = new HaobanResponse();
        response.setErrorCode(errCode.getCode());
        response.setMessage(errCode.getMsg());
        PrintWriter writer = null;
        try {
            httpServletResponse.setHeader("Content-type", "application/json;charset=UTF-8");
            writer = httpServletResponse.getWriter();
            writer.append(JSONObject.toJSONString(response));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @Override
    public boolean preHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o) throws Exception {
        String requestURI = httpServletRequest.getRequestURI();
        logger.info("post-url:{}", requestURI);
        Map<String, String[]> parameterMap = httpServletRequest.getParameterMap();
        logger.info("post-params:{}", JSONObject.toJSONString(parameterMap));
        HandlerMethod handler = (HandlerMethod) o;
        IgnoreLogin ignoreLogin = handler.getMethodAnnotation(IgnoreLogin.class);
        if (null != ignoreLogin) {
            return true;
        }
        WellDoneLoginDTO wellDoneLoginDTO = (WellDoneLoginDTO) AuthRequestWellDoneUtil.getLoginUser();
        if (wellDoneLoginDTO == null) {
            this.errorResult(httpServletResponse, HaoBanErrCode.ERR_30009);
            logger.info("用户不存在!");
            return false;
        }
        String wxEnterpriseId = wellDoneLoginDTO.getWxEnterpriseId();
        GicRateLimiter instance = GicRateLimiter.getInstance(MOUDLE);
        Long acquire = instance.acquire(requestURI, wxEnterpriseId);
        logger.info("限流返回值：{},{}", requestURI, acquire);
        if (acquire == 0L) {
            this.errorResult(httpServletResponse, HaoBanErrCode.ERR_13);
            logger.info("wxEnterpriseId:{},限流!", wxEnterpriseId);
            return false;
        }
        return true;
    }

    @Override
    public void postHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, ModelAndView modelAndView) throws Exception {
        logger.info("end");
    }

    @Override
    public void afterCompletion(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, Exception e) throws Exception {
        logger.info("end");
    }
}
